<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Stvori proračunsku tablicu</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Stvori novu proračunsku tablicu</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Poravnaj dolje</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Poravnavanje sadržaja odabranih ćelija na donjoj granici</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Poravnaj po sredini</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Poravnavanje sadržaja odabranih ćelija u sredinu</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Poravnaj lijevo</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Poravnavanje sadržaja odabranih ćelija na lijevoj granici</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Poravnaj desno</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Poravnavanje sadržaja odabranih ćelija na desnoj granici</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Poravnaj gore</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Poravnavanje sadržaja odabranih ćelija na gornjoj granici</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Okomito poravnaj</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Poravnavanje sadržaja odabranih ćelija u sredinu</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Izvezi Proračunsku Tablicu</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Izvoz proračunske tablice u CSV datoteku</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Uvezi Proračunsku Tablicu</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Uvoz CSV datoteke u proračunsku tablicu</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Spajanje ćelija</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Spajanja odabranih ćelija</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Postavite pseudonim</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Postavite pseudonim za odabrane ćelije</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Podijeli ćeliju</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Razdjeli prije spojene ćelije</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Podebljani tekst</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Postavi tekst u odabranim ćelijama podebljano</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Ukošeni tekst</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Postavi tekst u odabranim ćelijama ukošeno</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Podcrtavanje teksta</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Podcrtavanje teksta u odabranim ćelijama</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Prilagođena boja</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Spajanje ćelija</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Podijeli ćeliju</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation>Ćeliju poravnaj lijevo</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation>centriraj ćeliju</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation>Ćeliju poravnaj desno</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation>Ćeliju poravnaj  na gore</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation>Ćeliju poravnaj  na dolje</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation>Ćeliju centriraj uspravno</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation>Postavi podebljani tekst</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation>Postavi ukošeni tekst</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation>Postavi podcrtani tekst</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation>Stvori proračunsku tablicu</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation>Postavi svojstava ćelija</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>Uredi ćeliju</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Umetni redove</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Ukloni redove</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Umetni stupce</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation>Obriši ćeliju(e)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation>Postavi boju prednjeg plana</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation>Postavi boju pozadine</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Svojstva ćelije</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Boja</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekst</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Pozadina</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Poravnanje</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Vodoravno</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Lijevo</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Središte</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Desno</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Okomito</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Gore</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Ispod</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Podebljano</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Nakošeno</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Podcrtano</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Prikaži mjernu jedinicu</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Mjerna jedinica</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>&amp;Pseudonim</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Pseudonim za ovu ćeliju</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Sve (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Uvoz datoteke</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Izvoz datoteke</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Pokaži Proračunsku Tablicu</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Postavljanje boje prednjeg plana ćelije</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Postavlja boju prednjeg plana ćelije proračunske tablice</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Postavi boju pozadine ćelije</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Postavlja boju pozadine ćelije proračunske tablice</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Proračunska tablica ne podržava odabir raspona prilikom umetanja.
Odaberite samo jednu ćeliju.
</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Copy &amp; Paste nije uspjelo</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Pseudonim sadrži nevažeće znakove!

</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Referenca na ćeliju sa pseudonimom, na primjer
Spreadsheet.my_alias_name umjesto Spreadsheet.B1

</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Crna</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Bijela</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Crvena</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Tamno crvena</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Zelena</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Tamno zelena</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Plava</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Tamno plava</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Modra</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Tamno modra</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Ružičasta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Tamno ružičasta</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Žuta</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Tamno žuta</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Siva</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Tamno siva</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Svjetlo siva</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Prilagođena boja</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Obrazac</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Sadržaj:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>&amp;Pseudonim:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Referenca na ćeliju sa pseudonimom, na primjer
Spreadsheet.my_alias_name umjesto Spreadsheet.B1

</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Neimenovano</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Umetni redove</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Ukloni redove</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Umetni stupce</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Ukloni stupce</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Svojstva...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Proračunska tablica</translation>
    </message>
  </context>
</TS>
